gapipy.resources.dossier package
================================

Submodules
----------

gapipy.resources.dossier.accommodation_dossier module
-----------------------------------------------------

.. automodule:: gapipy.resources.dossier.accommodation_dossier
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.resources.dossier.activity_dossier module
------------------------------------------------

.. automodule:: gapipy.resources.dossier.activity_dossier
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.resources.dossier.place_dossier module
---------------------------------------------

.. automodule:: gapipy.resources.dossier.place_dossier
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.resources.dossier.transport_dossier module
-------------------------------------------------

.. automodule:: gapipy.resources.dossier.transport_dossier
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: gapipy.resources.dossier
    :members:
    :undoc-members:
    :show-inheritance:
